package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````R!8``#0```!4E@````0`!30`(``'
M`"@`'``;``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````A)``
M`(20```%```````!``$```"$D```A)`!`(20`0"X`@````,```8```````$`
M`@```)"0``"0D`$`D)`!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&2DB@``I(H``*2*```$`0``!`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$````RIH[!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-VAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````R!8````````#``L``````(R0`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#``"0
M(0``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``#R3`0``````$``5
M`#@``````````````!(```"9`P``8"P``!@````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,``$`W``!8
M````$@`+`(H``````````````!(```#(`P``A),!```````0`!4`3P``````
M````````$@```,`#```\DP$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``A),!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#```4)```)````!(`"P#@`P``
M."0``%`````2``L`[`,``-0M``#(!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0``@),!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``]$,```@!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``#B3`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``A),!```````0`!4`^@(`````````
M````$@```,\!`````````````!(```!'!```R!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$``"$DP$``````!``%0`6!```B"0``#@%```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0``/Q$``!0`0``$@`+`$$"`````````````!(````M!```/),!````
M```0`!4`.00``+P@``!<````$@`+`$$$```<1P``M`(``!(`"P!(`@``````
M```````2````1@0``,@6````````$@`+`$\"`````````````!(```!.!```
MF"$``'P"```2``L`6P0``'@L``!<`0``$@`+`%8"`````````````!(```!M
M!```P"D``)0````2``L`7P(`````````````$@```'`"`````````````!(`
M``#C`@`````````````2````=P(`````````````$@```'L$``!4*@``9```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``!$
MDP$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```F$,``%P````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P``])(!``0````1`!0`C`0``)PT``"D`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!S=')D=7``;&EB<'1H<F5A9"YS
M;RXQ`'!T:')E861?871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-VAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``(20`0`7````B)`!`!<```"8D@$`%P```*B2`0`7````N)(!`!<`
M``#$D@$`%P```,R2`0`7````W)(!`!<```#DD@$`%P```.R2`0`7````\)(!
M`!<```#TD@$`%P```/B2`0`7````"),!`!<````,DP$`%P```!23`0`7````
M&),!`!<````<DP$`%P```""3`0`7````)),!`!<````LDP$`%P```#"3`0`7
M````.),!`!<```"<D@$`%0<``*22`0`5%```K)(!`!4B``"PD@$`$2<``+22
M`0`2)P``P)(!`!4R``#(D@$`%38``-"2`0`5/```U)(!`!5"``#8D@$`%4<`
M`."2`0`55@``Z)(!`!5F``",D0$`%@,``)"1`0`6!```E)$!`!8%``"8D0$`
M%@<``)R1`0`6"```H)$!`!8)``"DD0$`%@H``*B1`0`6#```K)$!`!8.``"P
MD0$`%@\``+21`0`6$```N)$!`!82``"\D0$`%A8``,"1`0`6%P``Q)$!`!88
M``#(D0$`%AD``,R1`0`6&@``T)$!`!8;``#4D0$`%AT``-B1`0`6'@``W)$!
M`!8?``#@D0$`%B```.21`0`6(0``Z)$!`!8C``#LD0$`%B@``/"1`0`6*0``
M])$!`!8J``#XD0$`%BP``/R1`0`6+0```)(!`!8N```$D@$`%B\```B2`0`6
M,```#)(!`!8S```0D@$`%C0``!22`0`6-0``&)(!`!8W```<D@$`%CD``""2
M`0`6.@``))(!`!8[```HD@$`%CX``"R2`0`6/P``,)(!`!9!```TD@$`%D(`
M`#B2`0`60P``/)(!`!9$``!`D@$`%D<``$22`0`62```2)(!`!9)``!,D@$`
M%DL``%"2`0`63P``5)(!`!91``!8D@$`%E0``%R2`0`65P``8)(!`!98``!D
MD@$`%ED``&B2`0`66P``;)(!`!9<``!PD@$`%ET``'22`0`67@``>)(!`!9?
M``!\D@$`%F$``("2`0`68@``A)(!`!9C``"(D@$`%F4``(R2`0`6:0``D)(!
M`!9J``"4D@$`%FL```3@+>4$X)_E#N"/X`CPON7@?0$``,:/XA?*C.+@_;SE
M`,:/XA?*C.+8_;SE`,:/XA?*C.+0_;SE`,:/XA?*C.+(_;SE`,:/XA?*C.+`
M_;SE`,:/XA?*C.*X_;SE`,:/XA?*C.*P_;SE`,:/XA?*C.*H_;SE`,:/XA?*
MC.*@_;SE`,:/XA?*C.*8_;SE`,:/XA?*C.*0_;SE`,:/XA?*C.*(_;SE`,:/
MXA?*C.*`_;SE`,:/XA?*C.)X_;SE`,:/XA?*C.)P_;SE`,:/XA?*C.)H_;SE
M`,:/XA?*C.)@_;SE`,:/XA?*C.)8_;SE`,:/XA?*C.)0_;SE`,:/XA?*C.)(
M_;SE`,:/XA?*C.)`_;SE`,:/XA?*C.(X_;SE`,:/XA?*C.(P_;SE`,:/XA?*
MC.(H_;SE`,:/XA?*C.(@_;SE`,:/XA?*C.(8_;SE`,:/XA?*C.(0_;SE`,:/
MXA?*C.((_;SE`,:/XA?*C.(`_;SE`,:/XA?*C.+X_+SE`,:/XA?*C.+P_+SE
M`,:/XA?*C.+H_+SE`,:/XA?*C.+@_+SE`,:/XA?*C.+8_+SE`,:/XA?*C.+0
M_+SE`,:/XA?*C.+(_+SE`,:/XA?*C.+`_+SE`,:/XA?*C.*X_+SE`,:/XA?*
MC.*P_+SE`,:/XA?*C.*H_+SE`,:/XA?*C.*@_+SE`,:/XA?*C.*8_+SE`,:/
MXA?*C.*0_+SE`,:/XA?*C.*(_+SE`,:/XA?*C.*`_+SE`,:/XA?*C.)X_+SE
M`,:/XA?*C.)P_+SE`,:/XA?*C.)H_+SE`,:/XA?*C.)@_+SE`,:/XA?*C.)8
M_+SE`,:/XA?*C.)0_+SE`,:/XA?*C.)(_+SE`,:/XA?*C.)`_+SE`,:/XA?*
MC.(X_+SE`,:/XA?*C.(P_+SE`,:/XA?*C.(H_+SE`,:/XA?*C.(@_+SE`,:/
MXA?*C.(8_+SE`,:/XA?*C.(0_+SE`,:/XA?*C.((_+SE`,:/XA?*C.(`_+SE
M`,:/XA?*C.+X^[SE`,:/XA?*C.+P^[SE`,:/XA?*C.+H^[SE`,:/XA?*C.+@
M^[SE`,:/XA?*C.+8^[SE`,:/XA?*C.+0^[SE`!"@X0(`H.$'T,WC,P``ZD0P
MG^5$()_E`S"/X'!`+>D\4)_E`F"3YP50C^`&`%7A<("]*`%@1N(`0*#C!6!&
MX"9AH.$$,)7D,_\OX08`5.$!0(3B^O__&G"`O>B8>@$`&`$``)!Y`0!D()_E
M9#"?Y600G^4"((_@`P"2YP$PDN<#`%#A'O\O(?!!+>D!<$/B`'!'X`A0@.(`
M0*#CIW&@X0<``.H(8!7E"%"%X@`PEN4S_R_A!P!4X0%`A.(``(;E\(&]"`0P
M5>6@`%/C]/__"BC__^L\>@$`/`$``"`!``!P@9_E`&!1XH!`+>D(@(_@"-!-
MXDL```I<(9_E7#&?Y0(@F.<`8(+E"""6Y0-PF.<`,);E`""'Y0`@D^4``%+C
M.@``"C@1G^4!$)CG`""!Y0`@D^4`,-+E``!3XP4```H!((+B+P!3XP`@@04!
M,-+D``!3X_K__QH``%#C````"OC^_^N3___K^#"?Y0,PF.<``%/C-0``"NPP
MG^7L4)_E`Y"8YP50C^`)`%7A`9!),@6023``0*`S*9&@,00``"H$,)7D,_\O
MX0D`5.$!0(3B^O__&K@`G^6X4)_E``"/X.#^_^NP,)_E!5"/X`.`F.<(`%7A
M`8!(,@6`2#``0*`S*(&@,00``"H$,)7D,_\OX00`6.$!0(3B^O__&@`@E^4`
M$);E!`"6Y9$+`.NR_O_K3#"?Y60@G^4#,)CG`B"/X``@@^7+___J5#"?Y1/`
MH.,$`*#C`!"@XP,PC^`"(*#C`,"-Y?O^_^L!`*#CV/[_ZX3__^O'___JQ'D!
M`&0!```X`0``;`$``%P!```H`0``,'@!`$S^___L=P$`1`$``%1Z`0#(,```
M\$<MZ0"04.+$,)_E`S"/X"L```J\()_E`C"3YP"`D^4``%CC*```"@!0V>4!
M<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)CE``!4XPP```H(8*#A!`"@X04@
MH.$)$*#AD_[_ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@
MX?"'O>@)4*#A`3#UY0``4^,]`%,3^___&@E01>#F___J`5"%X@A@1N`%0(3@
M1F&@X0!@A^4$`*#A\(>]Z`E`H.'M___J"$"@X>O__^H<>`$`.`$``&`AG^5@
M,9_E`B"/X/!#+>D`4%#B`S"2YZ303>(`,)/EG#"-Y0`PH.,"```*`##5Y0``
M4^,*```:,"&?Y2@QG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.-!```:I-"-
MXO"#O>B7_O_K`$!0XO'__PK\@)_E#7"@X0B`C^`$`*#A`O__ZP``4.,G```*
M#3#0Y0U@@.(N`%/C`@``&@$PUN4``%/C]/__"@TPT.4N`%/C(@``"@4`H.'H
M_O_K`)"@X08`H.'E_O_K``")X`(`@.+H_O_K!C"@X04@H.$($*#A`&"@X=3^
M_^L'$*#A!@"@X5/^_^L!`'#C!@"@X0,```H(,)WE#SH#X@$)4^,2```*0O[_
MZP8`H.$W_O_K!`"@X=K^_^L``%#CU___&@0`H.%>_O_K!0"@X1K^_^N]___J
M`3#6Y2X`4^/9__\:`C#6Y0``4^/(__\*U?__ZJ?__^OK___J1?[_ZT1W`0!`
M`0``#'<!`'`O``"0()_ED#"?Y0(@C^`00"WIH-!-X@,PDN<`0*#A#1"@X0`P
MD^6<,(WE`#"@XR#^_^L``%#C``"@$P0``!H(,)WE#SH#X@H*4^,!"5,3"@``
M"D@@G^5`,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C!P``&J#0C>(0@+WH
M`A"@XP0`H.%M_O_K$`]OX:`"H.'N___J&_[_Z\QU`0!``0``?'4!```0H.'X
M`)_E,$`MZ0';3>+P,)_E#-!-X@``C^`$4(WB`2N@XP,PD.<%`*#A`#"3Y00T
MC>4`,*#CUOW_ZP$P0.(#`%7A"```*@4@C>(`$*#C`@``Z@(`4.$`$,#E`@``
M"@$P<.4O`%/C^?__"B\0H.,%`*#AUOW_ZP``4.,0```*!0!0X0`PH(,`,,"%
M!0"@X5#^_^MP()_E:#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XQ$``!H!
MVXWB#-"-XC"`O>A$()_E.#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XP4`
M`!HD`)_E``"/X`';C>(,T(WB,$"]Z#7^_^K7_?_K&'4!`$`!``"4=`$`9'0!
M`+`L``#P0"WI`&"@X?@`G^4!VTWB]#"?Y0S03>(``(_@!'"-X@%0H.'_(P#C
M`S"0YP<0H.'8`)_E`#"3Y00TC>4`,*#C``"/X,_]_^L`P%#B%P``V@%`3.(!
M.X3B"#"#X@,PC>`$-%/E``!3XR,``!H``%3C#@``"@0@H.$O$*#C!P"@X07^
M_^L``%#C"```"H``G^4``(_@)_[_ZP0PH.$'(*#A!A"@X0``D.4'_O_K!@``
MZF``G^4``(_@'O[_ZP4@H.$&$*#A``"0Y:+]_^M(()_E-#"?Y0(@C^`#,)+G
M`""3Y00TG>4"(#/@`#"@XP0``!H!VXWB#-"-XO"`O>@,0*#AV___ZI#]_^L`
M=`$`0`$``'PL``"X=`$`E'0!`$1S`0#P1RWI`4"@X0`PT>4(T$WB#!*?Y0!0
MH.$((I_E/0!3XP$0C^`!0(0"_(&?Y0(@D><$`*#A"("/X``@DN4$((WE`""@
MX_#]_^L-$*#A`&"@X04`H.&=_O_K`)!0XD$```KI_?_K``!6X3@``)J\,9_E
M`'"=Y0.`F.<'<:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@X0$@\^4`
M`%+C/0!2$_O__QH%,$/@`@"&X@!@F.4#`(#@V?W_ZP``4.,'`(;G%@``"@`0
MG>4%`*#A`""8Y0$PT.0!$9+G``!3XST`4Q,`,,'E!@``"@$@@>(!,-#D`A"@
MX0``4^,]`%,3`3#"Y/G__QH!(*#A/3"@XP`PP>4!,-3D``!3XP$PXN7[__\:
M""&?Y?@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,U```:"-"-XO"'O>@!
MD$GB`3#4Y```4^,!,.GE^___&N[__^K`,)_E`X"8YP!PF.4`,)?E``!3XR0`
M``H',*#A!""SY0D0H.$!D(GB``!2X_K__QH#$('B`1&@X9`PG^4#,(_@`""3
MY0``4N,/```:`0"@X0$@H.,`((/EE_W_ZP"@4.+5__\*!Q"@X0EQH.$'(*#A
MU_S_ZP"@B.4!,(GB`""@XP,ABN<`D(WEH?__Z@<`H.',_/_K``!0XP"@H.$`
M`(CEQ?__"@EQH.'R___J`Y"@X0@0H./?___J`?W_Z]AR`0!``0``Q'(!`#@!
M``#,<0$`1',!`$`@G^5`,)_E0`"?Y0(@C^!P0"WI``"/X`-@DN=N_?_K+%"?
MY2Q`G^4%4(_@!B"@X01`C^`%,*#A!!"@X7!`O>@``)#E&?W_ZK!P`0`D`0``
MV'$!`*1I``!$*0``7`"?Y3!`+>D``(_@%-!-XE!0G^59_?_K!5"/X`!`H.$`
M`)#EWO__ZP`0E.4X()_E``"@XS0PG^4,$(WE,!"?Y0,PC^`"()7G`1"/X`0`
MC>4`,(WE#`"=Y1C]_^L4T(WB,("]Z(AQ`0!(<`$`<`$``+0K``#L*`````"@
MXQ[_+^%$(I_E1#*?Y?!/+>D"((_@2]Y-X@!0H.$,T$WB,`*?Y0,PDN<88(WB
M``"/X`%PH.$$$$;B`#"3Y;0TC>4`,*#CW/W_ZR\0H.,`0*#A!0"@X8+\_^L`
M`%#C$```"O0!G^4%$*#A``"/X![__^L%`*#AY"&?Y=0QG^4"((_@`S"2YP`@
MD^6T-)WE`B`SX``PH.-L```:2]Z-X@S0C>+PC[WH!P"@X??\_^NP$9_E`1"/
MX*#\_^L`H%#BY___"@`PVN6<D9_EG(&?Y0``4^.8<9_E"9"/X`B`C^`'<(_@
M/@``"@``5.,$```*"A"@X00`H.$(_?_K``!0XRX```H*`*#A^_S_ZP$@0.(`
M,*#A`B"*X`"PH.$"`%KA`#"*,`$`BC(`$*`S`P``.@@``.H#`%#A`!##Y0(`
M``H!('/E+P!2X_G__PH*`*#AZ?S_ZP"PH.$%`*#AYOS_ZPL`@.`!`(#B`0M0
MX[S__RJTL(WB_!"?Y0<PH.$!*Z#C`1"/X`L`H.$$$(WE`!"@XPA0C>4`H(WE
M@/S_ZP80H.$+`*#A3?S_ZP``4.,#```:(#"=Y0\Z`^(""5/C%```"K00G^4`
M`*#C`1"/X%O\_^L`H%#BHO__"@`PVN4``%/CP/__&@``5.,5```*`##4Y2X`
M4^,"```*`;"@XPF@H.'4___J`3#4Y0``4^/K__\*^/__Z@$0H.,+`*#AC/S_
MZP``4./E__\:4`"?Y0L0H.$``(_@K?[_ZPL`H.&3_/_KC/__Z@&PH.,(H*#A
MP?__ZC'\_^O4;P$`0`$``*0H``!T*```:&\!`#PH``!\)P``>"<``!0H``#0
M)@``*"<``+`F```00"WI+Q"@XP!`H.']^__K``!0XP%`@!($`*#A$$"]Z'G\
M_^H00"WI`$!0X@D```H`,-3E``!3XP8```J-_/_K`0"`X@$+4.,&``"*!`"@
MX1!`O>CV_?_J$`"?Y1!`O>@``(_@:/S_Z@``H.,0@+WH<"4``,@DG^7(-)_E
M`B"/X'!`+>D(T$WBO&2?Y0,PDN<-0*#AM%2?Y09@C^``,)/E!#"-Y0`PH.,%
M4(_@!!"@X08`H.$@_?_K``!0XPX```J,-)_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I49)_E!F"/
MX`00H.$&`*#A"OW_ZP``4.,.```*-#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E
M``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J`&2?Y09@C^`$
M$*#A!@"@X?3\_^L``%#C#@``"MPSG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``
M4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZJQCG^4&8(_@!!"@
MX08`H.'>_/_K``!0XPX```J$,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C
M`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I88Y_E!F"/X`00H.$&
M`*#AR/S_ZP``4.,.```*+#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!
M@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J!&.?Y09@C^`$$*#A!@"@
MX;+\_^L``%#C#@``"M0RG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G
M\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZK!BG^4&8(_@!!"@X08`H.&<
M_/_K``!0XPX```I\,I_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'_
M_PH$,(/B!""3Y0``4N,$((/D^___&NO__^I<8I_E!F"/X`00H.$&`*#AAOS_
MZP``4.,.```*)#*?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKK___J"&*?Y09@C^`$$*#A!@"@X7#\_^L`
M`%#C#@``"LPQG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P
M@^($()/E``!2XP0@@^3[__\:Z___ZK1AG^4&8(_@!!"@X08`H.%:_/_K``!0
MXPX```IT,9_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B
M!""3Y0``4N,$((/D^___&NO__^I@89_E!F"/X`00H.$&`*#A1/S_ZP``4.,.
M```*'#&?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J#`&?Y000H.$``(_@+_S_ZP`04.("```*^`"?
MY0``C^!V_?_K\`"?Y000H.$``(_@)OS_ZP`04.("```*W`"?Y0``C^!M_?_K
MU`"?Y000H.$``(_@'?S_ZP`04.(2```*P`"?Y0``C^!D_?_KN""?Y60PG^4"
M((_@`S"2YP`@D^4$,)WE`B`SX``PH.,0```:F!"?Y9@`G^4!$(_@``"/X`C0
MC>)P0+WH5/W_ZH0`G^4$$*#A``"/X`3\_^L`$%#BZ?__"G``G^4``(_@2_W_
MZ^7__^K4^O_KZ&P!`$`!``#@)0``O&P!`#@!``"$)0``-"4``.@D``"8)```
M4"0``)@C``"L(P``8",``!0C``!$(@``;"(``$`B``!<(@``*"$``$PB``"`
M(0``A&@!`(PC``"8(0``^"$``(@A``!\()_E?#"?Y0(@C^!X`)_E!.`MY0S0
M3>(#,)+G``"/X`T0H.$`,)/E!#"-Y0`PH./6^__K``!0XP4```H``-#E``!0
MXS``4!,!`*`#``"@$P$`(.(T()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@
M`#"@XP$``!H,T(WB!/"=Y)GZ_^NP9P$`0`$``/0@``!<9P$`3,"?Y0\`+>D,
MP(_@1!"?Y03@+>4,T$WB`1"<YQ0@C>(T,)_E-`"?Y0`0D>4$$(WE`!"@XP,P
MC^``((WE$!"=Y0``D^>P`(#BV?K_Z_\`H.,^^O_K'&<!`$`!``#P9@$`:`$`
M`/!/+>D!V$WB@.&?Y1S03>)\P9_E`A"@XP[@C^``$(WE`1B-X@`@H.,,P)[G
M`#"@XQ00@>(`D*#A`,"<Y0#`@>4`P*#CT/K_ZP%@4.(`@,'BR"^@X0(P)N`"
M,%/@<S#_Y@(P(^`",%/@`B#"X`-@5N`"@,C@``!8XST``+H4L9_E"*"@XQ!Q
MG^4,4(WB"["/X`&@0.,'<(_@`!"@XP8@H.$(,*#A"0"@X0`0C>6V^O_K`0!Q
MXP$`<`,P```*"B"@X040H.$)`*#A;?K_ZP$`<.,?```*!P!0XR```)H(`$#B
M`$"5X`,``#H<``#J`4!$X@4`5.$9```Z"""@XP<0H.$$`*#AE/K_ZP``4./V
M__\:!4!$X`8`E.#$'ZC@?,"?Y0$XC>)H()_E%#"#X@S`C^`"()SG`,"2Y0`@
MD^4,P#+@`""@XQ```!H!V(WB'-"-XO"/O>A(`)_E``"/X([__^L!:%;B`(#(
MX@$`>.,!"'8#R/__&@``X.,`$*#AYO__Z@L`H.&$___KR___ZACZ_^NH9@$`
M0`$``/P?``"H9P$`E&4!`$`?```00"WI@OK_ZWOZ_^L``%#C``"0%1"`O>@P
M(9_E\$`MZ0(@C^`H89_E%-!-XB0QG^4($(WB!F"/X`!0H.$#,)+G!@"@X0`P
MD^4,,(WE`#"@XR;[_^L`0%#B`@``"@`PU.4``%/C#@``&NP@G^7D,)_E`B"/
MX`,PDN<`()/E##"=Y0(@,^``,*#C+P``&LP`G^4%$*#A``"/X!30C>+P0+WH
M7OS_Z@40H.&W^?_K``!0XPH```JH()_EF#"?Y0(@C^`#,)+G`""3Y0PPG>4"
M(#/@`#"@XQP``!H4T(WB\("]Z`4`H.%0^O_K`'"@X00`H.%-^O_K``"'X`(`
M@.)0^O_K8#"?Y6`0G^4%(*#A`S"/X`!`C>4!$(_@`$"@X3GZ_^M(()_E+#"?
MY0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP00H`$&`*`!TO__"K[Y_^OX9`$`
MR!X``$`!``"H9`$`:!X``%QD`0`4'0``$!T``/!C`0`\%I_E/,:?Y3PFG^4!
M$(_@#,"/X/!/+>D,,(SB`B"1YT??3>(`D*#A&%",X@`@DN44(8WE`""@XQAP
MC>('`)/H,."-XC#`C.(D0(WB%&"-XOBEG^4'`(?H"J"/X`\`M>@/`*[H`P"5
MZ`,`CN@'`)SH!P"$Z`80H.'4!9_E``"/X+WZ_^L`4%#B`@``"@`PU>4``%/C
M"0$`&GO__^L`4%#B[0``"@4`H.$"^O_K@`"@X0$`@.(%^O_K`"#5Y0``4N,`
M@*#A"0``"HBUG^4(0*#A"["/X`0`H.$+$*#A[/G_ZP$@]>4"0(3B``!2X_C_
M_QID!9_E-%"-X@``C^`"``#J!`"5Y```4.,-```*!A"@X9GZ_^L`0%#B^/__
M"@`PU.4``%/C]?__"BC[_^L``%#C\O__"@0`H.'#^?_K`$!0XA,``!H`4*#C
M1C^-X@4Q@^``01/E``!4XPP```H!L(7B"[&'X``PU.4``%/C!P``"@0`H.$!
M4(7B%/O_ZP``4.,W```:!$";Y```5./T__\:`$"@XP0`H.'&^?_K`%"@X0@`
MH.'#^?_K`%"%X`%;A>($4(7B!0"@X<3Y_^N<-)_EG!2?Y00@H.$#,(_@`#"-
MY9`TG^4!$(_@!("-Y0,PC^``<*#AJOG_ZP<=H.,'`*#A>OG_ZP$`<..%```*
M2!"-X@<`H.$>^?_K`$!0XAD```I4!)_E!S"@X5`4G^4`4*#C`""9Y0``FN<!
M$(_@L`"`XA_Y_^LX))_E##2?Y0(@C^`#,)+G`""3Y10QG>4"(#/@`#"@X_D`
M`!H%`*#A1]^-XO"/O>@$`*#A=_G_ZP!`4.*T__\*QO__ZE`PG>4/.@/B`0E3
MX^'__QID@)WE@_G_ZP``6.'=__\:4#"=Y5,PZ.<'#5/CV?__&@4`H.&'^?_K
M!A"@X0!0H.&X`Y_E``"/X"WZ_^L`$%#BD0``"@``F>4[_/_K`(!0XHT```H(
M`*#A=/G_ZP,`4.,`8*#A#```FH03G^4$`$#B``"(X`$0C^!U^?_K``!0XP4`
M`!H$`%;CNP``"@9@B.`%,%;E+P!3X[<```HP_O_K`&!0X@0``!H(`*#A!A"@
MX4_Y_^L`@%#B=0``&C03G^4T`Y_E`1"/X#"3G^4``(_@+(.?Y5+[_^LH8Y_E
M+/G_ZR0CG^4D,Y_E"9"/X"`3G^4"((_@`S"/X`0@C>4!$(_@!R"@X0B`C^`&
M8(_@``"-Y04`H.$\^?_K#0``Z@3Y_^L`,)#E$0!3XPX``!H8^?_K`4"$X@DP
MH.$'(*#A"!"@X5``C>D`P*#A!0"@X0#`C>4M^?_K!QV@XP4`H.']^/_K`0!P
MX^S__PH'`*#AEOC_ZZ`"G^4%$*#A``"/X"C[_^L%`*#AI/[_ZX?__^KH^/_K
M`#"0Y1$`4^-U__\*`$"9Y>/X_^LX$I_E!S"@X0!0H.,$(*#A`,"0Y0$`FN=8
M$I_EL`"`X@#`C>4!$(_@EOC_ZW7__^H%L*#A1C^-X@LQ@^#T`!/E``!0XR``
M``H!@(OB"%&$X`80H.$(L*#AO/G_ZP`P4.("```*`##3Y0``4^,$```:!`"5
MY```4.,3```*`8"(XO+__^KE^/_K`%!0XNC__PKX_O_J=_[_Z]PAG^5\,9_E
M`B"/X`,PDN<`()/E%#&=Y0(@,^``,*#C50``&@4`H.%'WXWB\$^]Z-3X_^H-
M`*#CJ%&?Y?+X_^M3(*#C!5"/X`"`H.'L_O_J`("9Y6___^KP_?_K`*!1X@"0
MH.&%__^Z"B!0X@!@C>7@8(WB`##*X@@`H.'*^/_K!B"@XP80H.$(`*#AA/C_
MZP8`4.,"```*3`&?Y0``C^#%_?_KX""=Y4,\H.-!,T3C`P!2X7'__QJT(-;A
M2#4$XP,`4N%M__\:,B!9XNA`C>(`,,KB`!"@XP@`H.$`$(WEL?C_ZR@@H.,(
M`*#A!!"@X6OX_^LH`%#C`@``"NP`G^4``(_@K/W_Z^0`G^4`(*#CX#"?Y>`0
MG^4``(_@$"'-Y0,PC^`$`(WE`1"/X`<@H.$%`*#A`$"-Y:3X_^MZ___J!&"9
MY0``5N-$__\*!@"@X:?X_^L#`%#C0/__FIP0G^4$`$#B``"&X`$0C^"I^/_K
M``!0XP:`H`$X___J)/C_ZYAC`0`090$`0`$``$QC`0`4'```T!P``!P;``#L
M&P``U!L``#`:``!H`0``T!L``&AA`0"0&P``6!L``(0;``"H&0``G!@```0;
M``"H&P``P!L``)`8``#\&@``D!@``&P9``#87@$`D!@```09``"@&```7!D`
M`"@6``"$&```,!@``$PBG^5,,I_E`B"/X$@"G^7P0"WI#-!-X@,PDN<``(_@
M#6"@X0`PD^4$,(WE`#"@XW'X_^L&$*#A`#"0Y1P"G^5D(-/E``"/X&4@P^48
M^?_K``!0XP(```H`,-#E,0!3XV0```K@^__K]`&?Y?1!G^4``(_@8/C_ZP1`
MC^`#,*#C`2"@XP00H.$`4*#A``"0Y?SW_^L`0%#B"@``"@PPE.7$(9_E``"5
MY0`0D^4"((_@V??_ZPPPE.4`$)/E"#"1Y0$%$^-7```:H`&?Y:!!G^4``(_@
M2/C_ZP1`C^`#,*#C`2"@XP00H.$`4*#A``"0Y>3W_^L`0%#B"0``"G0!G^4&
M$*#A``"/X.GX_^L`(%#B/```"@PPE.4``)7E`!"3Y;WW_^M0`9_E4'&?Y0``
MC^`Q^/_K2!&?Y0$@H.,'<(_@`1"/X`!0D.4`0*#A!0"@X=CW_^LL(9_E`B"/
MX``0H.$%`*#AK/?_ZP`PE.48`9_E`""@XP80H.$``(_@92##Y<OX_^L``%#C
M"`"'Y1$```H'':#CW_?_ZP$@@.(`,*#A$0!0XP$`4A,B``"*W""?Y:`PG^4"
M((_@`S"2YP`@D^4$,)WE`B`SX``PH.,8```:#-"-XO"`O>@$`)?EU?W_ZP``
M4.,(`(?EZ/__&J``G^4``(_@LO?_ZP$PT.4``%/CF/__"I;__^J(,)_E#""4
MY0,PC^`$,)/E``"2Y0`0D^6G^?_KOO__Z@``E>6V]__KI/__ZG7W_^M<()_E
M7`"?Y0(@C^```(_@!@"2Z0`0D>6;]__KU%P!`$`!``#P70$`U!4``)Q=`0!D
M%P``-!<``#Q=`0`0%P``T!0``.!<`0"070$`K!8``*P6``!0%```*%L!`!P6
M``"\7`$`C%P!`.P5```00"WI`$"@X9S\_^L``%3C``!0$Q"`O0@`,-3E``!3
MXQ"`O0@$`*#A,OO_ZRC[_^L<$)_E!""@XP$0C^`@]__K``!0XQ"`O1@$`*#A
M$$"]Z*7X_^H0%```\$\MZ5/?3>+DZY_E!#"-XN`KG^4<$(#B#N"/X%S`@.(`
M0*#A`P"@X0(@GN<`()+E1"&-Y0`@H.,$()'D`0!<X3(OO^8$((#D^O__&OP`
M@^(-(*#A`A"@X03`LN4X,)'E)."1Y0``4N$,$)'E#C`CX`$P(^`,,"/@XS^@
MX4`P@N7S__\:(%"4Z9DY!^,$`)WE@CI%XP!@E.40<)3E#A`LX`,`@.`%$`'@
M!P"`X&61H.$.$"'@"""=Y>8-@.!F@:#A`0"`X`D0+.`#((+@!A`!X`X@@N`,
M$"'@`A"!X`P@G>7@'8'@`R""X`R@@N`(("G@`"`"X&`!H.$)("+@"B""X!"@
MG>7A+8+@`Z"*X`F@BN``D"C@`9`)X&$1H.$(D"G@"I")X!2@G>7BG8G@`Z"*
MX`B@BN`!@"#@`H`(X&(AH.$`@"C@`K`AX`J`B.`8H)WE";`+X.F-B.`#H(K@
M`*"*X&D!H.$!D"O@`+`BX`J0B>`<H)WE"+`+X.B=B>`#H(K@`:"*X&@1H.$"
M@"O@`;`@X`J`B.`@H)WE";`+X.F-B.`#H(K@`J"*X&DAH.$`D"O@`K`AX`J0
MB>`DH)WE"+`+X.B=B>`#H(K@`*"*X&@!H.$!@"O@`+`BX`J`B.`HH)WE";`+
MX.F-B.`#H(K@`:"*X&D1H.$"D"O@`;`@X`J0B>`LH)WE"+`+X.B=B>`#H(K@
M`J"*X&@AH.$`@"O@`K`AX`J`B.`PH)WE";`+X.F-B.`#H(K@`*"*X&D!H.$!
MD"O@`+`BX`J0B>`TH)WE"+`+X.B=B>`#H(K@`:"*X&@1H.$"@"O@`;`@X`J`
MB.`XH)WE";`+X.F-B.`#H(K@`J"*X&DAH.$`D"O@`K`AX`J0B>`\H)WE"+`+
MX.B=B>`#H(K@`*"*X&@!H.$!@"O@`+`BX`J`B.!`H)WE";`+X.F-B.`#H(K@
M`:"*X&D1H.$"D"O@`;`@X`J0B>!$H)WE"+`+X.B=B>`#H(K@`J"*X&@AH.$`
M@"O@"H"(X$B@G>7IC8C@`Z"*X```BN`"H"'@":`*X&F1H.$!H"K@`*"*X$P`
MG>7HK8K@`P"`X`$`@.`)$"+@"!`!X&B!H.$"$"'@`!"!X%``G>7J'8'@`S"`
MX`@`*>`*``#@`B"#X`D`(."A.P[C`@"`X%0@G>79/D;C:J&@X0,@@N#A#8#@
M"9""X%@@G>4#((+@""""X`J`*.`!@"C@"(")X&&1H.%<$)WEX(V(X`,0@>`*
M$('@":`JX`"@*N!@`:#A"J""X&`@G>7HK8K@`R""X`D@@N``D"G@")`IX&B!
MH.$)D('@9!"=Y>J=B>`#$('@`!"!X`@`(.`*`"#@:J&@X0``@N!H()WEZ0V`
MX`,@@N`(((+@"H`HX`F`*.!ID:#A"("!X&P0G>7@C8C@`Q"!X`H0@>`)H"K@
M`*`JX&`!H.$*H(+@<""=Y>BMBN`#((+@"2""X`"0*>`(D"G@:(&@X0F0@>!T
M$)WEZIV)X`,0@>``$('@"``@X`H`(.!JH:#A``""X'@@G>7I#8#@`R""X`@@
M@N`*@"C@"8`HX&F1H.$(@('@?!"=Y>"-B.`#$('@"A"!X`F@*N``H"K@8`&@
MX0J@@N"`()WEZ*V*X`,@@N`)((+@`)`IX`B0*>!H@:#A"9"!X(00G>7JG8G@
M:K&@X0,0@>``$('@"``@X`H`(.``((+@Z:V"X(@@G>4#((+@""""X`N`*.`)
M`"C@:9&@X0`0@>",`)WEZHV!X`D0*^`#`(#@"A`AX`L`@."0L)WE:J&@X0$0
M@N`#L(O@Z!V!X`FPB^`*D"G@""`IX&B!H.$"((#@X9V"X)0@G>4#((+@"B""
MX`B@*N`!`"K@F*"=Y6$1H.$``(O@`Z"*X.D-@.`(H(K@`8`HX`F`*.!ID:#A
M"(""X)P@G>7@C8C@I+"=Y0,@@N`!((+@"1`AX``0(>!@`:#A`:"*X``0*>#H
MK8K@"!`AX`$@@N!H@:#AZAV"X*`@G>4#((+@"#`@X`D@@N!JD:#A`Z`JX-P\
M"^,;/TCC"B""X`.PB^`)H(CA`+"+X*@`G>7A+8+@`:`*X`,`@.!A$:#A"`"`
MX`F`".`(H(KA`8")X0N@BN`"@`C@`;`)X.*MBN`+@(CAL+"=Y0``B.!B(:#A
MZHV`X*P`G>4#L(O@`P"`X`&PB^`)D(#@`@"!X0H``.`"$`'@`1"`X6JAH.$)
MD('@"A""X>@-B>"TD)WE"!`!X&B!H.$#D(G@`I")X`H@`N`"(('A"!"*X0NP
M@N``$`'@""`*X."]B^`"$('AN""=Y0D0@>"\D)WE8`&@X0,@@N`*H(+@`Y")
MX``@B.$(D(G@"R`"X`"`".#K'8'@"(""X6NQH.$*H(C@"R"`X6&!H.'AK8K@
M`2`"X,`0G>4#$('@`!"!X`L``.```(+A"""+X0D`@.`*(`+@")`+X.H-@.`)
M((+AR)"=Y0$0@N#$()WE:J&@X0.0B>`#((+@")")X`NP@N`*((CA`"`"X`J`
M".#@'8'@"(""X6`!H.$+L(C@`""*X6&!H.'AO8O@`2`"X,P0G>4#$('@"A"!
MX`"@"N`*H(+A"""`X0F0BN`+(`+@"*``X.N=B>`*((+AU*"=Y0$0@N#0()WE
M:[&@X0.@BN`#((+@"*"*X```@N`+((CA"2`"X`N`".#I'8'@"(""X6F1H.$`
M`(C@"2"+X>&-@.`!(`+@80&@X=@0G>4#$('@"Q"!X`FP"^`+L(+A`"")X0J@
MB^`((`+@`+`)X.BMBN`+((+AX+"=Y0$0@N#<()WE:(&@X0.PB^`#((+@`+"+
MX`F0@N`(((#A"B`"X`@``.#J'8'@``""X6JAH.$)D(#@"B"(X6$!H.'AG8G@
M`2`"X.00G>4#$('@"!"!X`J`".`(@(+A`""*X0N`B.`)(`+@`+`*X.F-B.`+
M((+A[+"=Y0$@@N#H$)WE:9&@X0.PB^`#$('@`+"+X`J@@>`)$(#A"!`!X`D`
M`.#H+8+@``"!X0J@@.!H@:#AX@V*X/"@G>4($(GA`S"*X`(0`>`),(/@8B&@
MX0B0">`"H(CA"1"!X0"@"N`+$('@`K`(X.`=@>`+H(KA8)&@X0,PBN#T`)WE
MX:V#X-8Q#.-B.DSC`P"`X&&QH.$(@(#@^`"=Y0,`@.`"`(#@"2`BX`$@(N#\
M$)WE`H"(X`L@*>#JC8C@"B`BX`,0@>!JH:#A"1"!X`J0*^`(D"G@`@"`X`F0
M@>`$$9WE`"&=Y>@-@.`#$('@:(&@X0H0@>`#((+@"*`JX`L@@N``H"K@X)V)
MX`J@@N`((9WE8`&@X>FMBN`#((+@""""X`"`*.`)@"C@:9&@X0B`@>`,$9WE
MZHV(X`,0@>``$('@"0`@X`H`(.!JH:#A``""X!`AG>7H#8#@`R""X`D@@N`*
MD"G@")`IX&B!H.$)D('@%!&=Y>"=B>`#$('@"A"!X`B@*N``H"K@8`&@X0J@
M@N`8(9WEZ:V*X`,@@N`(((+@`(`HX`F`*.!ID:#A"("!X!P1G>7JC8C@`Q"!
MX``0@>`)`"#@"@`@X&JAH.$``(+@("&=Y>@-@.`#((+@"2""X`J0*>`(D"G@
M:(&@X0F0@>`D$9WEX)V)X`,0@>`*$('@"*`JX`"@*N!@`:#A"J""X"@AG>7I
MK8K@`R""X`@@@N``@"C@"8`HX&F1H.$(@('@+!&=Y>J-B.`#$('@`!"!X`D`
M(.`*`"#@:J&@X0``@N`P(9WEZ`V`X`,@@N`)((+@"I`IX`B0*>!H@:#A"1"!
MX#21G>7@'8'@`Y")X`J0B>`(H"K@`*`JX&`!H.$*((+@.*&=Y>$M@N`#H(K@
M"*"*X`"`*.`!@"C@81&@X0B0B>`\@9WEXIV)X`.`B.``@(C@`0`@X`(`(.!B
M(:#A``"*X`)PA^#I#8#@$'"$Y6#!C.`(P(3E0,&=Y0,PC.`&,(/@`3"#X`(0
M(>`)$"'@:9&@X0$0B.`)("+@X!V!X``@(N`",(/@2""?Y0%0A>#A'8/@.#"?
MY0(@C^`$4(3E">".X``0A.4,X(3E`S"2YP`@D^5$,9WE`B`SX``PH.,!```:
M4]^-XO"/O>A']/_KR%D!`$`!```D3@$`$$`MZ6``H.._]/_K`""@XP'#`N.)
M&PKC1<=&X\T?3N,`P(#E_LP-XP00@.6ZR$GC=A0%XPC`@.4R$$'C%""`Y0P0
M@.7P$0[C&""`Y=(33.-<((#E$!"`Y1"`O>CP1RWI`I"@X10PD.6"(:#A`%"@
MX0%`H.$",)/@&""0Y10P@.4<@(7B7`"0Y0$@@B*I+H+@&""%Y0``4.,.```*
M0&!@X@``B.`&`%GA"6"@L08@H.$1]/_K7#"5Y0,PAN!<,(7E0`!3X_"'O1@%
M`*#A!I!)X`9`A.#)_/_K/P!9XQX``-I`D$GB*6.@X0%PAN('<X3@!!"@X4!`
MA.((,*#A`."1Y1`0@>(,P!'E$#"#X@@`$>4$(!'E!`!1X1#@`^4,P`/E"``#
MY00@`^7S__\:!0"@X0%`H.&Q_/_K!P!4X>O__QH&DTG@"2"@X0<0H.$(`*#A
MZ?/_ZUR0A>7PA[WH!'"@X??__^KP02WI''"!XA0@D>4!0*#A&&"1Y0!0H.'2
M,>7G,H^_Y@$@@^)_$.#C.`!2XS9OO^8"`(?@`Q#'YT```-I`(&+B`!"@X_'S
M_^L$`*#ADOS_ZU``P/(L,(3B#PI']`\*0_0\,(3B#PI#]$PPA.(/!T/T!`"@
MX51@A.58@(3EAOS_ZP,PU.4$`*#A`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E
M`#"4Y0,PQ>4',-3E!##%Y;8PU.$%,,7E!#"4Y2,TH.$&,,7E!#"4Y0<PQ>4+
M,-3E"##%Y;HPU.$),,7E"#"4Y2,TH.$*,,7E"#"4Y0LPQ>4/,-3E###%Y;XP
MU.$-,,7E##"4Y2,TH.$.,,7E##"4Y0\PQ>43,-3E$##%Y;(QU.$1,,7E$#"4
MY2,TH.$2,,7E$#"4Y1,PQ>7P0;WH>O/_ZC@@8N(`$*#CL//_Z\?__^I<,)_E
M$$`MZ0,PC^!40)_E)"#3Y01`C^```%+C$("]&$0@G^4!$*#C)!##Y0(PE.<`
M`%/C`@``"C`PG^4#`)_G3?/_ZR@PG^4#,)3G``!3XQ"`O0@<`)_E$$"]Z```
MC^"Z\__J[$P!`!A+`0`<`0``:$P!`%0!``!D10``/!"?Y3PPG^4!$(_@`S"/
MX``@T>4``%+C'O\O$2@@G^4!`*#C``#!Y0(PD^<``%/C'O\O`10`G^4$$('B
M``"/X*SS_^IP3`$`I$H!`%@!```(10``5,*?Y50RG^5P0"WI#,"/X"#03>)(
M4I_E%`"-Y10`C>(0$(WE$!"-X@P@C>4,((WB`S"<YP50C^``,)/E'#"-Y0`P
MH.-X\__K&"*?Y1@RG^4"()7G`P"5YP(0H.%^\__K"#*?Y0,PE><`0-/E``!4
MXU(```KX`9_E``"/X+[S_^L48)WE`""0Y00`AN('`7#C`V"&XD8STN4#,(/C
M1C/"Y6,``(H``:#A4_/_Z\0AG^400)WE`B"/X+P1G^4!$(_@!`""Y0`PH.$`
M()3E`""`Y:@AG^4"((_@!""`Y:`AG^44`)WE`B"5YP$`4.,,$(/E`""2Y0@@
M@^52``#:!!"$X@S`@^(`083@!."1Y`$`5.$$X*SE^___&@,`@.)D09_E`!"@
MXP`0C>4&(*#A`!&#YP1`C^!0$9_E#`"4Y0$0C^!:\__K``!0XRD```H\49_E
M&&"-X@50C^`,`)7E"//_ZP80H.$`0*#A)`&?Y0``C^`O]/_K``!0XR````H4
M,9_E`S"/X`P`D^7N\O_K-?/_ZP0AG^7$,)_E`B"/X`,PDN<`()/E'#"=Y0(@
M,^``,*#C*```&@0`H.$@T(WB<("]Z/CR_^O4()_E`B"/X```4.,,`(+E'0``
M"L[R_^O``)_E``"/X&3S_^L`,)#EYD7#Y9___^H,`)3E1_/_Z]+__^H(`)7E
M``!0XP$```J$^__KV?__ZHP`G^4&$*#A``"/X`/T_^L``%#C"`"%Y=+__PKU
M___J<#"?Y7``G^4#$)7G``"/X/[R_^L$`*#CLO__Z@$`H..+\O_KS/+_ZU!*
M`0!``0``*$H!`%`!``!@`0``+`$``!1+`0"82P$`/`4``"`%``!,`0``'$L!
M`+C8___X2@$`/`(``,Q*`0#$2`$`A$H!`*Q)`0`L`0``2`$``/0"``!P<U]S
M=')I;F=S(&UI<W-I;F<*`"]T;7`O````+@```%!!4E]435!$25(``%1%35!$
M25(`5$U0`%5315(`````55-%4DY!344`````)7,O)7,````O<')O8R]C=7)P
M<F]C+V5X90```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5`````!005)?5$5-4`````!005)?4%)/1TY!344`````
M.@```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]05`````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M``!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'````
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D`$Q$7TQ)
M0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D
M```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U
M+25U)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].
M`````#$N,#8Q````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````$-!0TA%```!&P,[``$``!\````T
MC/__&`$``(R,__\T`0``!(W__U0!``"LCO__I`$``(B/___(`0```)'___0!
M``"DD?__&`(``+R2__]0`@``W)/__X`"```8EO__L`(``'26___4`@``[);_
M__0"``#TEO__"`,``'"9__]``P``E)G__V`#``#DF?__B`,``!R?__^X`P``
ML)___]@#```4H/___`,``+RA__\T!```U*'__TP$```PH___A`0``/BI___,
M!```G*S___0$``#TK/__/`4``/2X__]P!0``4+G__X@%``!8NO__K`4``*B[
M__^$`0``)+S__W`!``!XO/__%`4``!```````````7I2``)\#@$;#`T`&```
M`!@````4B___6`````!(#A"$!(4#A@*.`1P````T````4(O__W@`````4@X8
MA`:%!88$AP.(`HX!&````%0```"HB___J`$```!&#@B'`HX!1`X0`!````!P
M````K+K__U0`````````'````(0````<NO__?`````!$#@B$`HX!:L[$#@``
M```@````I`````"-___<`````$(.((0(A0>&!H<%B`2)`XH"C@$H````R```
M`+B-__]X`0```$@.'(0'A0:&!8<$B`.)`HX!1@[``6(*#AQ""R````#T````
M!(___Z0`````2`X(A`*.`4(.J`%R"@X(0@L``#0````8`0``A(___Q@!````
M1@X,A`.%`HX!0@Z,"$0.F`@"5`H.#$(+6@H.#$+.Q<0.`$(+````+````%`!
M``!DD/__(`$```!"#A2$!84$A@.'`HX!1@Z4"$0.H`@"<`H.%$(+````+```
M`(`!``!4D?__/`(```!"#B"$"(4'A@:'!8@$B0.*`HX!1@XH`IX*#B!""P``
M(````+`!``!@D___7`````!*#A"$!(4#A@*.`5;.QL7$#@``'````-0!``"8
MD___>`````!$#@R$`X4"C@%$#B!H#@P0````]`$``/"3__\(`````````#0`
M```(`@``Y)/__WP"````1@XDA`F%"(8'AP:(!8D$B@.+`HX!1`[4"40.X`D"
M0`H.)$(+````'````$`"```HEO__)`````!"#@B$`HX!3L[$#@`````D````
M8`(``"R6__]0`````$(."(0"C@%6"L[$#@!""T0*SL0.`$0++````(@"``!4
MEO__.`4```!(#A"$!(4#A@*.`4(.&`-$`@H.$$+.QL7$#@!""P``'````+@"
M``!<F___E`````!*#@2.`4(.$'(*#@1""P`@````V`(``-";__]D`````$0.
M$(`$@0."`H,!1@X4C@5"#B`T````_`(``!"<__^H`0```$(.)(0)A0B&!X<&
MB`6)!(H#BP*.`4(.I(`$1`[`@`0"H`H.)$(+`!0````T`P``@)W__Q@`````
M0@X(A`*.`30```!,`P``@)W__UP!````1`X4A`6%!(8#AP*.`48.*'@*#A1"
MSL?&Q<0.`$(+7`H.%$(+````1````(0#``"DGO__R`8```!,#B2$"84(A@>'
M!H@%B02*`XL"C@%&#L`"`QX!"@XD0@L#1@$*#B1"SLO*R<C'QL7$#@!""P``
M)````,P#```DI?__I`(```!*#A2$!84$A@.'`HX!0@X@`MX*#A1""QP```#T
M`P``H*?__U@`````0@X(A`*.`6;.Q`X`````)````!0$``!<M___M`(```!&
M#A"$!(4#A@*.`40.,`+4"@X00@L``#`````\!```L*?__P`,````0@XDA`F%
M"(8'AP:(!8D$B@.+`HX!0@[P`@/R!0H.)$(+```4````<`0``'RS__]<````
M`$(."(0"C@$@````B`0``,"S__\(`0```$(.((0(A0>&!H<%B`2)`XH"C@$L
M````K`0``*2T__]0`0```$(.&(0&A06&!(<#B`*.`0*<"L[(Q\;%Q`X`0@L`
M````````R$8``$Q&`````````0````$````!````RP(```$```#5`@```0``
M`.H"```!````"0,```\```"B!```&0```(20`0`;````!````!H```"(D`$`
M'`````0````$````>`$```4```!T"P``!@```+0$```*````ZP0```L````0
M````%0`````````#````@)$!``(````8`@``%````!$````7````>!$``!$`
M``!@$```$@```!@!```3````"````/O__V\````(^O__;Q<`````````````
M````````````````````````````````````````````D)`!````````````
MD!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3
M``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,`
M`)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``
MD!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``(R0
M`0````````````````"$D`$`````````````````@),!````````````B)`!
M```````XDP$`````````````````D)`!``````!$DP$``````/22`0"<-```
M0),!`/B2`0`*4$%2+G!M"@````#D20``[$D```````#P20``]$D``/Q)``!P
M2@``!$H````````(2@``$$H````````@30``1T-#.B`H3F5T0E-$(&YB,R`R
M,#(S,3`P."D@,3`N-2XP`$=#0SH@*&YB,R`R,#(S,3`P."D@,3`N-2XP`"1.
M971"4T0Z(&-R=#`N4RQV(#$N-"`R,#$X+S$Q+S(V(#$W.C,W.C0T(&IO97)G
M($5X<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L=B`Q+C(W(#(P,C(O,#8O
M,C$@,#8Z-3(Z,3<@<VMR;&P@17AP("0`)$YE=$)31#H@8W)T:2Y3+'8@,2XQ
M(#(P,3(O,#@O,3,@,#(Z-#DZ,#0@;6%T="!%>'`@)``D3F5T0E-$.B!C<G1B
M96=I;BYC+'8@,2XQ-R`R,#$X+S$R+S(X(#$X.C$W.C$Q(&-H<FES=&]S($5X
M<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XR(#(P,3,O,3(O,C`@,34Z,S4Z
M-#@@:F]E<F<@17AP("0`\<\"``````````````````@````(````"`````@`
M```;`````0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D("HJ*@``\<\"
M``````````````````@````(````"`````@````;`````0``````````*BHJ
M($YO($QA8F5L(%!R;W9I9&5D("HJ*@!!,@```&%E86)I``$H````!3<M00`&
M"@=!"`$)`@H##`$2!!0!%0$7`Q@!&@(<`2(!1`$`+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N;F5T8G-D+FED96YT`"YN;W1E+FYE=&)S9"YP87@`+FYO=&4N
M;F5T8G-D+FUA<F-H`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N
M9&%T80`N8G-S`"YC;VUM96YT`"Y354Y77V-T9@`N05)-+F%T=')I8G5T97,`
M+FYO:6YI=```````````````````````````````````````````````````
M``````L````!`````@```!0!```4`0``%P```````````````0`````````3
M````!P````(````L`0``+`$``!@```````````````0`````````)@````<`
M```"````1`$``$0!```4```````````````$`````````#<````'`````@``
M`%@!``!8`0``(```````````````!`````````!*````!0````(```!X`0``
M>`$``#P#```&``````````0````$````4`````L````"````M`0``+0$``#`
M!@``!P````,````$````$````%@````#`````@```'0+``!T"P``ZP0`````
M`````````0````````!@````"0````(```!@$```8!```!@!```&````````
M``0````(````:0````D```!"````>!$``'@1```8`@``!@```!,````$````
M"````&T````!````!@```)`3``"0$P``.`,`````````````!`````0```!R
M`````0````8```#(%@``R!8```@S``````````````0`````````>`````$`
M```"````T$D``-!)``#30``````````````$`````````(`````!`````@``
M`*2*``"DB@``!`$`````````````!`````````".`````0````(```"HBP``
MJ(L``-P$``````````````0`````````F`````X````#````A)`!`(20```$
M```````````````$````!````*0````/`````P```(B0`0"(D```!```````
M````````!`````0```"P`````0````,```",D`$`C)````0`````````````
M``0`````````M0````8````#````D)`!`)"0``#P````!P`````````$````
M"````+X````!`````P```("1`0"`D0``=`$`````````````!`````0```##
M`````0````,```#TD@$`])(``$@```````````````0`````````R0````@`
M```#````0),!`#R3``!$``````````````!``````````,X````!````,```
M```````\DP``/0```````````````0````$````?`````0```#``````````
M>9,``!\!``````````````$````!````UP````$``````````````)B4``"/
M```````````````$`````````.$````#``!P```````````GE0``,P``````
M`````````0````````#Q`````0````$```"$DP$`6I4`````````````````
M``$``````````0````,``````````````%J5``#Y```````````````!````
$````````
